( cd usr/bin ; rm -rf gnome-panel-screenshot )
( cd usr/bin ; ln -sf gnome-screenshot gnome-panel-screenshot )
( cd usr/share/doc/gnome-utils-2.12.2 ; rm -rf build )
( cd usr/share/doc/gnome-utils-2.12.2 ; ln -sf /usr/src/garnome-Ptgz-kit build )
#%% begin initialize gnome_utils-2.12.2-i386-P1
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -q || exit 1
fi
GCONFTOOL=/usr/bin/gconftool-2
if [ ! -x $GCONFTOOL ]; then
  exit 1
fi
GCONF_CONFIG_SOURCE=`$GCONFTOOL --get-default-source`
export GCONF_CONFIG_SOURCE
GCONF_DIR=/usr/etc/gconf
SCHEMA_DIR=$GCONF_DIR/schemas
SCHEMA_FILES=" \
  gdict.schemas \
  gnome-screenshot.schemas \
  gnome-search-tool.schemas \
  logview.schemas \
  "
for s in $SCHEMA_FILES; do
  $GCONFTOOL --makefile-install-rule $SCHEMA_DIR/$s > /dev/null
done
#%% end
